pub struct CheatScript {
pub id: CheatScriptId,
pub script: String,
}Fields
id: CheatScriptIdscript: StringTrait Implementations
Sourceimpl Clone for CheatScript
impl Clone for CheatScript
Sourcefn clone(&self) -> CheatScript
fn clone(&self) -> CheatScript
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheatScript
impl Debug for CheatScript
Sourceimpl<'de> Deserialize<'de> for CheatScript
impl<'de> Deserialize<'de> for CheatScript
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CheatScript
impl JsonSchema for CheatScript
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CheatScript
impl Serialize for CheatScript
Sourceimpl Tsify for CheatScript
impl Tsify for CheatScript
const DECL: &'static str = "export interface CheatScript {\n id: CheatScriptId;\n script: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>